==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSelectEnclosedPoints.java <==
// java wrapper for vtkSelectEnclosedPoints object
//

package vtk;
import vtk.*;

public class vtkSelectEnclosedPoints extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSurfaceData_2(vtkPolyData id0);
  public void SetSurfaceData(vtkPolyData id0)
    { SetSurfaceData_2(id0); }

  private native void SetSurfaceConnection_3(vtkAlgorithmOutput id0);
  public void SetSurfaceConnection(vtkAlgorithmOutput id0)
    { SetSurfaceConnection_3(id0); }

  private native long GetSurface_4();
  public vtkPolyData GetSurface() {
    long temp = GetSurface_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSurface_5(vtkInformationVector id0);
  public vtkPolyData GetSurface(vtkInformationVector id0) {
    long temp = GetSurface_5(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInsideOut_6(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_6(id0); }

  private native void InsideOutOn_7();
  public void InsideOutOn()
    { InsideOutOn_7(); }

  private native void InsideOutOff_8();
  public void InsideOutOff()
    { InsideOutOff_8(); }

  private native int GetInsideOut_9();
  public int GetInsideOut()
    { return GetInsideOut_9(); }

  private native void SetCheckSurface_10(int id0);
  public void SetCheckSurface(int id0)
    { SetCheckSurface_10(id0); }

  private native void CheckSurfaceOn_11();
  public void CheckSurfaceOn()
    { CheckSurfaceOn_11(); }

  private native void CheckSurfaceOff_12();
  public void CheckSurfaceOff()
    { CheckSurfaceOff_12(); }

  private native int GetCheckSurface_13();
  public int GetCheckSurface()
    { return GetCheckSurface_13(); }

  private native int IsInside_14(int id0);
  public int IsInside(int id0)
    { return IsInside_14(id0); }

  private native void SetTolerance_15(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_15(id0); }

  private native double GetToleranceMinValue_16();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_16(); }

  private native double GetToleranceMaxValue_17();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_17(); }

  private native double GetTolerance_18();
  public double GetTolerance()
    { return GetTolerance_18(); }

  private native void Initialize_19(vtkPolyData id0);
  public void Initialize(vtkPolyData id0)
    { Initialize_19(id0); }

  private native int IsInsideSurface_20(double id0,double id1,double id2);
  public int IsInsideSurface(double id0,double id1,double id2)
    { return IsInsideSurface_20(id0,id1,id2); }

  private native int IsInsideSurface_21(double id0[]);
  public int IsInsideSurface(double id0[])
    { return IsInsideSurface_21(id0); }

  private native void Complete_22();
  public void Complete()
    { Complete_22(); }

  public vtkSelectEnclosedPoints() { super(); }

  public vtkSelectEnclosedPoints(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-21-armv7h.pkg.tar.xz: vtk/vtkSelectEnclosedPoints.java <==
// java wrapper for vtkSelectEnclosedPoints object
//

package vtk;
import vtk.*;

public class vtkSelectEnclosedPoints extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSurfaceData_2(vtkPolyData id0);
  public void SetSurfaceData(vtkPolyData id0)
    { SetSurfaceData_2(id0); }

  private native void SetSurfaceConnection_3(vtkAlgorithmOutput id0);
  public void SetSurfaceConnection(vtkAlgorithmOutput id0)
    { SetSurfaceConnection_3(id0); }

  private native long GetSurface_4();
  public vtkPolyData GetSurface() {
    long temp = GetSurface_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSurface_5(vtkInformationVector id0);
  public vtkPolyData GetSurface(vtkInformationVector id0) {
    long temp = GetSurface_5(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInsideOut_6(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_6(id0); }

  private native void InsideOutOn_7();
  public void InsideOutOn()
    { InsideOutOn_7(); }

  private native void InsideOutOff_8();
  public void InsideOutOff()
    { InsideOutOff_8(); }

  private native int GetInsideOut_9();
  public int GetInsideOut()
    { return GetInsideOut_9(); }

  private native void SetCheckSurface_10(int id0);
  public void SetCheckSurface(int id0)
    { SetCheckSurface_10(id0); }

  private native void CheckSurfaceOn_11();
  public void CheckSurfaceOn()
    { CheckSurfaceOn_11(); }

  private native void CheckSurfaceOff_12();
  public void CheckSurfaceOff()
    { CheckSurfaceOff_12(); }

  private native int GetCheckSurface_13();
  public int GetCheckSurface()
    { return GetCheckSurface_13(); }

  private native int IsInside_14(int id0);
  public int IsInside(int id0)
    { return IsInside_14(id0); }

  private native void SetTolerance_15(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_15(id0); }

  private native double GetToleranceMinValue_16();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_16(); }

  private native double GetToleranceMaxValue_17();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_17(); }

  private native double GetTolerance_18();
  public double GetTolerance()
    { return GetTolerance_18(); }

  private native void Initialize_19(vtkPolyData id0);
  public void Initialize(vtkPolyData id0)
    { Initialize_19(id0); }

  private native int IsInsideSurface_20(double id0[]);
  public int IsInsideSurface(double id0[])
    { return IsInsideSurface_20(id0); }

  private native int IsInsideSurface_21(double id0,double id1,double id2);
  public int IsInsideSurface(double id0,double id1,double id2)
    { return IsInsideSurface_21(id0,id1,id2); }

  private native void Complete_22();
  public void Complete()
    { Complete_22(); }

  private native int IsSurfaceClosed_23(vtkPolyData id0);
  public int IsSurfaceClosed(vtkPolyData id0)
    { return IsSurfaceClosed_23(id0); }

  public vtkSelectEnclosedPoints() { super(); }

  public vtkSelectEnclosedPoints(long id) { super(id); }
  public native long   VTKInit();

}
